@@ -1,6 +1,3 @@
 from __future__ import absolute_import, unicode_literals
 
-pytest_plugins = [
-    str('barril.fixtures'),
-]
-
+pytest_plugins = [str("barril.fixtures")]
